/** @file button.c
 * @par Programm:
 *                 Quellen und Lautstrkesteller
 *
 * @author         Achill Hasler (AHC)
 * @date           05.12.08
 *
 * @par Copyright:
 *                 AH Consulting GmbH
 *
 * @par Compiler:
 *                 avr c fr ATmega48 / 88
 *
 * @brief          Taster der Encoder.
 *
 * @par History:
 *  <table>
 *    <tr><td>wann</td><td>ver</td><td>wer</td><td>was</td></tr>
 *    <tr><td>01.12.08</td><td>1.0.0</td><td>aha</td><td>
 *    erste version fertig
 *    </td></tr>
 *    <tr><td>05.12.08</td><td>1.0.1</td><td>aha</td><td>
 *    fertiggestellt.
 *    </td></tr>
 *  </table>
 */

#include "preamp.h"
#include "timer.h"
#include "relais.h"


void test_power_button(void)
{
  static uint8_t last_power_button = _BV(BUTT_CA);
  static uint16_t time = 0;

  uint8_t data;
  data = INPUT_PIN & _BV(BUTT_CA);  /* -> 1 ist offen, 0 ist gedrckt */

  if (time == 0 && (data != last_power_button)) {
    set_ticks(&time);
  }
  if (after_ms(&time, 2)) {
    if (data != last_power_button) {
      if (last_power_button != 0) { /* nur auf drcken reagieren */
        if (state == off) {
          /* wenn mute gedrueckt, dann alle Kanal offsets loeschen */
          uint8_t volume_button = INPUT_PIN & _BV(BUTT_VO);
          if (volume_button == 0) { /* Taste gedrckt */
            reset_channel_volume();
          }
          switch_on();
        }
        else if (state >= on) {
          switch_off();
        }
      }
      last_power_button = data;
    }
    time = 0;
  }
}


void test_volume_button(void)
{
  static uint8_t last_volume_button = _BV(BUTT_VO);
  static uint16_t time = 0;

  uint8_t data;
  data = INPUT_PIN & _BV(BUTT_VO);

  if (time == 0 && (data != last_volume_button)) {
    set_ticks(&time);
  }
  if (after_ms(&time, 2)) {
    if (data != last_volume_button) {
      if (data != 0) { /* nur auf loslassen reagieren */
        if (state == on) {
          mute_on();
        }
        else if (state == mute) { 
          mute_off();
        }
        else if (state == cancel_mute) {
          /* hab die lautstaeke eines Kanals verstellt oder bin nach dem einschalten
             noch auf der mute taste, also kein mute */
          state = on;
        }
      }
      last_volume_button = data;
    }
    time = 0;
  }
}
