/** @file eeprom.c
 * @par Programm:
 *                 Quellen und Lautstrkesteller
 *
 * @author         Achill Hasler (AHC)
 * @date           05.12.08
 *
 * @par Copyright:
 *                 AH Consulting GmbH
 *
 * @par Compiler:
 *                 avr c fr ATmega48 / 88
 *
 * @brief          EPROM Werte.
 *
 * @par History:
 *  <table>
 *    <tr><td>wann</td><td>ver</td><td>wer</td><td>was</td></tr>
 *    <tr><td>26.11.08</td><td>1.0.0</td><td>aha</td><td>
 *    erste version fertig
 *    </td></tr>
 *    <tr><td>06.12.08</td><td>1.0.1</td><td>aha</td><td>
 *    mute darf nicht gesetzt sein beim einschalten.
 *    </td></tr>
 *  </table>
 */

#include "preamp.h"

#ifdef PREAMP_USE_EPROM

#include <avr/eeprom.h>

uint8_t ee_channel EEMEM = _BV(0);
uint8_t ee_volume EEMEM = 0xe8;

/** volume offset von allen kanlen, wert darf -CHANNEL_MAX_OFFSET .. CHANNEL_MAX_OFFSET annehmen */
int8_t ee_channel_vol_offset[] EEMEM = {
 0, 
 0,
 0,
 0,
 0
};

/*
 * schreibe aktuelle werte ins eeprom
 */
void write_defaults(void)
{
  if (vol.bits.volume > 90) {
    /* zu laut, limitiere */
    vol.bits.volume = 90;
  }

  /* schreiben ins eprom */
  eeprom_write_byte(&ee_channel, chan.bits.input);
  eeprom_write_byte(&ee_volume, vol.bits.volume);
  eeprom_write_block(channel_vol_offset, ee_channel_vol_offset, sizeof(channel_vol_offset));
}


/*
 * lese defaults von eeprom
 */
void read_defaults(void)
{
  // lesen von eprom
  chan.bits.input = eeprom_read_byte(&ee_channel);
  vol.bits.volume = eeprom_read_byte(&ee_volume);
  eeprom_read_block(channel_vol_offset, ee_channel_vol_offset, sizeof(channel_vol_offset));

  /* leider zeigt die zuweisung bei der definition keine wirkung desshalb
     hier die initialisationswerte setzen
  */
  if (chan.bits.input == 0x1f) {
    /* eeprom wurde nocht nie beschrieben, dies sind die startwerte */
    vol.bits.volume =  52;
    chan.value = _BV(0);
    reset_channel_volume();
  }
  vol.bits.mute = 1;  /* mute Relais nicht gesetzt */
}

#else /* PREAMP_USE_EPROM */

void write_defaults(void)
{
}

void read_defaults(void)
{
  vol.value = 0x8a;
  chan.value = _BV(0);
  reset_channel_volume();
}
#endif /* PREAMP_USE_EPROM */
