/** @file rc5.h
 * @par Programm:
 *                 Quellen und Lautstrkesteller
 *
 * @author         Achill Hasler (AHC)
 * @date           05.12.08
 *
 * @par Copyright:
 *                 AH Consulting GmbH
 *
 * @par Compiler:
 *                 avr c fr ATmega48 / 88
 *
 * @brief          Inlude fr Infrarot RC5 Befehle.
 *
 * @par History:
 *  <table>
 *    <tr><td>wann</td><td>ver</td><td>wer</td><td>was</td></tr>
 *    <tr><td>26.11.08</td><td>1.0.0</td><td>aha</td><td>
 *    erste version fertig
 *    </td></tr>
 *    <tr><td>05.12.08</td><td>1.0.1</td><td>aha</td><td>
 *    verbessert.
 *    </td></tr>
 *  </table>
 */

#ifndef PREAMP_RC5_H_
#define PREAMP_RC5_H_

#ifdef PREAMP_USE_IR

#include "ir-rc5.h"

#define RC5_AMP1 16
#define RC5_TUNER 17
#define RC5_AMP2 19
#define RC5_CD 20 /* Philips cd FB RD 6910 */

/* Power */
#define RC5_POWER 12
#define RC5_STANDBY 61

/* Startwerte einstellen */
#define RC5_IDEAL 14  /* habe leider keine Taste dafr */
#define RC5_DISPLAY 15  /* liegt bei mir auf Info Taste */

#define PREAMP_RC5_RESET RC5_DISPLAY  /* sollte eigentlich RC5_IDEAL sein */

/* Lautstrke */
#define RC5_VOLUME_UP 16
#define RC5_VOLUME_DOWN 17
#define RC5_MUTE 13

/* Lautstrke des aktuellen kanals */
#define RC5_7 7
#define RC5_9 9
#define PREAMP_RC5_CHANNEL_VOLUME_UP RC5_9
#define PREAMP_RC5_CHANNEL_VOLUME_DOWN RC5_7

/* Inputkanal direktwahl */
#define RC5_1 1
#define RC5_2 2
#define RC5_3 3
#define RC5_4 4
#define RC5_5 5

/* Inputkanal vrwrts, rckwaerts */
#define RC5_CANNEL_UP 32
#define RC5_CANNEL_DOWN 33
#define RC5_INDEX_UP 34
#define RC5_INDEX_DOWN 35
#define RC5_VORWARD 52
#define RC5_REWIND 50


/**
 * Pollingfunktion fr rc5 verarbeitung
 */
void test_ir(void);

#endif /* PREAMP_USE_IR */

#endif /* PREAMP_IR_RC5_H_ */
