/** @file relais.h
 * @par Programm:
 *                 Quellen und Lautstrkesteller
 *
 * @author         Achill Hasler (AHC)
 * @date           05.12.08
 *
 * @par Copyright:
 *                 AH Consulting GmbH
 *
 * @par Compiler:
 *                 avr c fr ATmega48 / 88
 *
 * @brief          Inlude fr Relais steuerung.
 *
 * @par History:
 *  <table>
 *    <tr><td>wann</td><td>ver</td><td>wer</td><td>was</td></tr>
 *    <tr><td>26.11.08</td><td>1.0.0</td><td>aha</td><td>
 *    erste version fertig
 *    </td></tr>
 *    <tr><td>05.12.08</td><td>1.0.1</td><td>aha</td><td>
 *    verbessert.
 *    </td></tr>
 *  </table>
 */

#ifndef PREAMP_RELAIS_H_
#define PREAMP_RELAIS_H_

extern uint16_t power_relais_time;


/**
 * anpassen des kanals wenn ntig
 */
void adjust_channel(void);


/**
 * anpassen der lautstrke wenn ntig
 */
void adjust_volume(void);


/**
 * Setzt die inputrelais auf undefiniert
 */
void input_relais_reset(void);


/**
 * stellt gert ein
 */
void switch_on(void);


/**
 * stellt gert aus
 */
void switch_off(void);


/**
 * Ende funktion fr main-relais
 * nach switch_on oder switch_off aufrufen
 */
void main_relais_swiched(void);


/**
 * Main Power Relais einschalten
 */
inline void power_relais_on(void)
{
  PW_PORT |= _BV(PW_REL);
}


/**
 * Main Power Relais ausschalten
 */
inline void power_relais_off(void)
{
  PW_PORT &= ~_BV(PW_REL);
}

#endif /* PREAMP_RELAIS_H_ */
