/** @file timer.c
 * @par Programm:
 *                 Quellen und Lautstrkesteller
 *
 * @author         Achill Hasler (AHC)
 * @date           05.12.08
 *
 * @par Copyright:
 *                 AH Consulting GmbH
 *
 * @par Compiler:
 *                 avr c fr ATmega48 / 88
 *
 * @brief          Zeitfunktionen.
 *
 * @par History:
 *  <table>
 *    <tr><td>wann</td><td>ver</td><td>wer</td><td>was</td></tr>
 *    <tr><td>26.11.08</td><td>1.0.0</td><td>aha</td><td>
 *    erste version fertig
 *    </td></tr>
 *    <tr><td>02.12.09</td><td>1.0.1</td><td>aha</td><td>
 *    verbessert.
 *    </td></tr>
 *  </table>
 */

#include "preamp.h"
#include "timer.h"

volatile tick_count_t tick_count;			/* ein Tick alle 100 us */

/**
 * Interrupt Handler fr Timer/Counter 2(A)
 */
#ifdef DOXYGEN
void interrupt_TIMER2_COMPA_vect(void)
#else
#if defined(__AVR_ATmega88__) || defined(__AVR_ATmega48__)
ISR(TIMER2_COMPA_vect)
#else
ISR(SIG_OUTPUT_COMPARE2)
#endif
#endif
{
  uint32_t ticks = tick_count.u32; /* TickCounter [100 us] erhoehen */
  ticks++;
  tick_count.u32 = ticks; /* optimiert volatile weg, weil Ints eh aus sind */
}


/*
 * Stellt den tick_counter
 */
void set_ticks(uint16_t* ticks)
{
  *ticks = tick_count.u16;
  if (*ticks == 0) {
    /* ticks darf nicht 0 sein, sonst funktioniert after_ms nicht */
    *ticks = 0xffff;
  }
}


uint8_t after_ms(uint16_t* old_ticks, uint16_t ms)
{
  if (*old_ticks != 0) {
    uint16_t ms_ticks = MS_TO_TICKS(ms);
    uint16_t diff_time = tick_count.u16 - *old_ticks;
/*
    uint16_t now = tick_count.u16;
    uint16_t diff_time = (now >= *old_ticks)
                       ? now - *old_ticks
                       : 0xffff - *old_ticks + now + 1;

   new  = 250 11111010
   old  =  15 00001111
   diff = 235 11101011

   new =  250 11111010
   old =  255 11111111
   diff =  -5 11111011 + carry
   diff = -5 -> diff = msste 251 sein !

   diff = 11111011 ist 251

   desshalb reicht einfache zuweisung von (neg) resultat
    uint16_t diff_time = tick_count.u16 - *old_ticks;

*/

    if(diff_time > ms_ticks) {   /* zeit vorbei */
      /* zeit nachstellen, dammit es immer after bleibt */
      *old_ticks += ms_ticks;
      return (1);
    }
  }
  return (0); 
}
